widget_snippet library

Classes

TerminalStyle
Style for the terminal display mode.
WidgetSnippet
A Flutter widget that enables developers to easily showcase and share snippets of their widgets in package example apps, documentation, and presentations.
WidgetSnippetConfig
Configuration for widget snippet displays.

Enums

DisplayMode
Display mode for widget snippets.